import { BasicColumn, FormSchema } from '/@/components/Table';
import { optionsListApi, optionTypeListApi,optionsStatusListApi } from '/@/api/tigerapi/wms/delivery';
import { h, unref } from 'vue';
import { Tag } from 'ant-design-vue';
import { useI18n } from '/@/hooks/web/useI18n';
import { useLocale } from '/@/locales/useLocale';
const { t:bt } = useI18n();
const { getLocale } = useLocale();

export const columns: BasicColumn[] = [
  {
    title: bt('送货单号'),
    dataIndex: 'DELIVERY_NO',
    width: 200,
    resizable:true,
    sorter:true
  },
  // {
  //   title: bt('送货类型'),
  //   dataIndex: 'DELIVERY_TYPE',
  //   width: 180,
  //   customRender: ({ record }) => {
  //     const status = record.DELIVERY_TYPE;
  //     let text = '';
  //     let color = '';
  //     switch (status) {
  //       case 1:
  //         text = bt('普通');
  //         color = '#C2C247';
  //         break;
  //       case 2:
  //         text = bt('补货');
  //         color = 'blue';
  //         break;
  //       case 3:
  //         text = bt('备品');
  //         color = 'green';
  //         break;
  //       case 4:
  //         text = bt('样品');
  //         color = 'red';
  //         break;
  //       case 5:
  //         text = bt('VMI');
  //         color = 'red';
  //         break;
  //       default:
  //         break;
  //     }
  //     return h(Tag, { color: color }, () => text);
  //   },
  // },
  {
    title: '送货日期',
    dataIndex: 'DELIVERY_DATE',
    width: 180,
    resizable:true,
    sorter:true
  },
  {
    title: bt('创建时间'),
    dataIndex: 'CREATE_TIME',
    width: 180,
    resizable:true,
    sorter:true
  },
  {
    title: bt('修改时间'),
    dataIndex: 'UPDATE_TIME',
    width: 180,
    resizable:true,
    sorter:true
  },
  // {
  //   title: bt('状态'),
  //   dataIndex: 'STATUS',
  //   width: 180,
  //   customRender: ({ record }) => {
  //     const status = record.STATUS;
  //     let text = '';
  //     let color = '';
  //     switch (status) {
  //       case 0:
  //         text = bt('新建');
  //         color = '#C2C247';
  //         break;
  //       case 1:
  //         text = bt('待签收');
  //         color = '#C2C247';
  //         break;
  //       case 2:
  //         text = bt('签收中');
  //         color = 'blue';
  //         break;
  //       case 3:
  //         text = bt('已完成');
  //         color = 'green';
  //         break;
  //       case 4:
  //         text = bt('作废');
  //         color = 'red';
  //         break;
  //       default:
  //         break;
  //     }
  //     return h(Tag, { color: color }, () => text);
  //   },
  // },
  {
    title: '供应商名称',
    dataIndex: 'SUPP_NAME',
    width: 180,
    resizable:true,
    sorter:true
  },
  {
    title: bt('采购类型'),
    dataIndex: 'PURCHASE_TYPE',
    width: 180,
    customRender: ({ record }) => {
      const status = record.PURCHASE_TYPE;
      let text = '';
      let color = '';
      switch (status) {
        case 0:
          text = bt('一般采购');
          color = 'green';
          break;
        case 1:
          text = bt('委外采购');
          color = 'blue';
          break;
        default:
          break;
      }
      return h(Tag, { color: color }, () => text);
    },
    resizable:true,
    sorter:true
  },
  {
    title: bt('创建人'),
    dataIndex: 'CREATE_USER',
    width: 180,
    resizable:true,
    sorter:true
  }
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'DELIVERY_NO',
    label: bt('送货单号'),
    colProps: { span: 8 },
    component: 'Input',
  },
  // {
  //   field: 'ERP_BILL_CODE',
  //   label: bt('收料单'),
  //   colProps: { span: 8 },
  //   component: 'Input',
  // },
  {
    field: 'RECEIVE_DATE',
    label: bt('收货日期'),
    colProps: { span: 8 },
    component: 'RangePicker',
  },
  {
    field: 'STATUS',
    label: bt('状态'),
    component: 'ApiSelect',
    componentProps: {
      api: optionsListApi,
      resultField: 'Data',
      labelField: 'Desc',
      valueField: 'Value',
      // onChange: (e, v) => {
      //   alert(e)
      //   console.log('ApiSelect====>:', e, v);
      // },
    },
    colProps: { span: 8 },
  },
  {
    field: 'PURCHASE_TYPE',
    label: bt('采购类型'),
    component: 'ApiSelect',
    componentProps: {
      api: optionTypeListApi,
      resultField: 'Data',
      labelField: 'Desc',
      valueField: 'Value',
      // onChange: (e, v) => {
      //   alert(e)
      //   console.log('ApiSelect====>:', e, v);
      // },
    },
    colProps: { span: 8 },
  },
  // {
  //   field: 'STATUS',
  //   label: '状态',
  //   component: 'Select',
  //   colProps: { span: 8 },
  //   componentProps: {
  //     options: [
  //       {
  //         label: '新建',
  //         value: 0,
  //         key: 0,
  //       },
  //       {
  //         label: '待检',
  //         value: 1,
  //         key: 1,
  //       },
  //       {
  //         label: '检验中',
  //         value: 2,
  //         key: 2,
  //       },
  //       {
  //         label: '完成',
  //         value: 3,
  //         key: 3,
  //       }
  //     ],
  //   },

  // },
];

//送货单(WMS)明细
export const columns_D: BasicColumn[] = [

  // {
  //   title: bt('单据代码'),
  //   dataIndex: 'BILLCODE',
  //   width: 200,
  // },
  // {
  //   title: bt('物料编码'),
  //   dataIndex: 'ITEM_CODE',
  //   width: 200,
  // },
  // {
  //   title: bt('送货单号'),
  //   dataIndex: 'DELIVERY_NO',
  //   width: 200,
  // }, 
  {
    title: bt('送货单行号'),
    dataIndex: 'LINE_NO',
    width: 100,
    resizable:true,
    sorter:true
  },
  {
    title: bt('物料编码'),
    dataIndex: 'ITEM_CODE',
    width: 200,
    resizable:true,
    sorter:true
  },
  {
    title: bt('物料名称'),
    dataIndex: 'ITEM_NAME',
    width: 200,
    resizable:true,
    sorter:true
  },
  {
    title: bt('修改时间'),
    dataIndex: 'UPDATE_TIME',
    width: 180,
    resizable:true,
    sorter:true
  },
  // {
  //   title: '签收状态',
  //   dataIndex: 'SOURCECODE',
  //   width: 180,
  //   customRender: ({ record }) => {
  //     const status = record.SOURCECODE;
  //     let text = '';
  //     let color = '';
  //     // switch (status) {
  //     //   case 0:
  //     //     text = '待签收';
  //     //     color = '#C2C247';
  //     //     break;
  //     //   case 1:
  //     //     text = '签收中';
  //     //     color = 'orange';
  //     //     break;
  //     //   case 2:
  //     //     text = '已完成';
  //     //     color = 'blue';
  //     //     break;
  //     //   default:
  //     //     break;
  //     // }
  //     if(status==null)
  //     {
  //         text = '待签收';
  //         color = '#C2C247';
  //     }else{
  //         text = '已签收';
  //         color = 'green';
  //     }
  //     return h(Tag, { color: color }, () => text);
  //   },
  //   resizable:true,
  //   sorter:true
  // },
  // {
  //   title: bt('状态'),
  //   dataIndex: 'STATUS',
  //   width: 180,
  //   customRender: ({ record }) => {
  //     console.log('record', record);
  //     const status = record.STATUS;
  //     let text = '';
  //     let color = '';
  //     switch (status) {
  //       case '0':
  //         text = bt('新增');
  //         color = 'blue';
  //         break;
  //       case '1':
  //         text = bt('作业中');
  //         color = '#C2C247';
  //         break;
  //       case '2':
  //         text = bt('完成');
  //         color = '#C2C247';
  //         break;
  //       case '3':
  //         text = bt('调拨完成');
  //         color = 'green';
  //         break;
  //       default:
  //         break;
  //     }
  //     return h(Tag, { color: color }, () => text);
  //   },
  // },
  // {
  //   title: bt('出库仓库代码'),
  //   dataIndex: 'OUTWAREHOUSECODE',
  //   width: 200,
  // },
  // {
  //   title: bt('仓库代码'),
  //   dataIndex: 'WAREHOUSECODE',
  //   width: 200,
  // },
  // {
  //   title: bt('单位数量'),
  //   dataIndex: 'UNITCODE',
  //   width: 200,
  // },
  // {
  //   title: bt('需求数量'),
  //   dataIndex: 'PRQTY',
  //   width: 200,
  // },
   {
    title: bt('数量'),
    dataIndex: 'QTY',
    width: 200,
    resizable:true,
    sorter:true
  },
  {
    title: bt('计价数量'),
    dataIndex: 'VALUATION_QTY',
    width: 200,
    resizable:true,
    sorter:true
  },
]

export const columns_S: BasicColumn[] = [
  // {
  //   title: bt('条码'),
  //   dataIndex: 'SN',
  //   width: 200,
  // },
  {
    title: bt('物料编码'),
    dataIndex: 'ITEM_CODE',
    width: 200,
    resizable:true,
    sorter:true
  },
  {
    title: bt('修改时间'),
    dataIndex: 'UPDATE_TIME',
    width: 180,
    resizable:true,
    sorter:true
  },
   {
    title: bt('小包条码'),
    dataIndex: 'SMALL_BARCODE',
    width: 200,
    resizable:true,
    sorter:true
  },
   {
    title: bt('大包条码'),
    dataIndex: 'BIG_BARCODE',
    width: 200,
    resizable:true,
    sorter:true
  },
   {
    title: bt('外箱条码'),
    dataIndex: 'OUTER_BARCODE',
    width: 200,
    resizable:true,
    sorter:true
  },
  // {
  //   title: bt('单据代码'),
  //   dataIndex: 'BUSINESSLINE',
  //   width: 200,
  // },
  // {
  //   title: bt('单据日期'),
  //   dataIndex: 'BILLDATE',
  //   width: 200,
  // },
  {
    title: bt('生产日期'),
    dataIndex: 'PROD_DATE',
    width: 200,
    resizable:true,
    sorter:true
  },
  {
    title: bt('状态'),
    dataIndex: 'STATUS',
    width: 180,
    customRender: ({ record }) => {
      const status = record.STATUS;
      let text = '';
      let color = '';
      switch (status) {
        case 0:
          text = '不存在';
          color = 'green';
          break;
        case 10:
          text = '送货中';
          color = 'blue';
          break;
        case 20:
          text = '待检验';
          color = 'green';
          break;
        case 30:
          text = '待入库';
          color = '#C2C247';
          break;
        case 40:
          text = '在库中';
          color = 'blue';
          break;
        case 50:
          text = '已下架';
          color = 'green';
          break;
        case 60:
          text = '已发料';
          color = 'red';
          break;
        case 70:
          text = '已上料';
          color = 'red';
          break;
        case 80:
          text = '已耗尽';
          color = 'green';
          break;
        case 90:
          text = '已退料';
          color = 'green';
          break;
        case 100:
          text = '已发货';
          color = 'green';
          break;
        default:
          break;
      }
      return h(Tag, { color: color }, () => text);
    },
  },
 
  {
    title: bt('数量'),
    dataIndex: 'QTY',
    width: 200,
    resizable:true,
    sorter:true,
  },
];

export const searchFormSchema_D: FormSchema[] = [
  {
    field: 'ITEM_CODE',
    label: bt('物料编码'),
    colProps: { span: 8 },
    component: 'Input',
  },
  // {
  //   field: 'LINESTATUS',
  //   label: bt('状态'),
  //   component: 'ApiSelect',
  //   colProps: { span: 8 },
  //   componentProps: {
  //     api: optionsListApi,
  //     resultField: 'Data',
  //     labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
  //     valueField: 'Value',
  //   },
  // }
];
export const searchFormSchema_S: FormSchema[] = [
  // {
  //   field: 'BUSINESSLINE',
  //   label: bt('单据代码'),
  //   colProps: { span: 8 },
  //   component: 'Input',
  // },
  {
    field: 'ITEM_CODE',
    label: bt('物料编码'),
    colProps: { span: 8 },
    component: 'Input',
  },
  // {
  //   field: 'SN',
  //   label: bt('条码'),
  //   colProps: { span: 8 },
  //   component: 'Input',
  // },
  {
    field: 'STATUS',
    label: bt('状态'),
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: {
      api: optionsStatusListApi,
      resultField: 'Data',
      labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
      valueField: 'Value',
    },
  }
];
